import { ItemBucketMetadata, Client } from 'minio';
type UploadedObjectInfo = {
  etag: string;
  lastModified: Date;
  size: number;
  versionId: string;
  metadata: ItemBucketMetadata;
};

export interface OssBaseOperation {
  /**
   * 获取对象
   * @param objectName 对象名
   */
  getObject(objectName: string): Promise<any>;
  /**
   * 上传对象
   * @param objectName 对象名
   * @param data 数据
   */
  putObject(objectName: string, data: Buffer | string, metaData?: ItemBucketMetadata): Promise<UploadedObjectInfo>;
  /**
   * 上传文件
   * @param objectName 对象名
   * @param filePath 文件路径
   */
  fPutObject(objectName: string, filePath: string, metaData?: ItemBucketMetadata): Promise<UploadedObjectInfo>;
  /**
   * 获取对象信息
   * @param objectName 对象名
   */
  statObject(objectName: string): Promise<any>;
  /**
   * 删除对象
   * @param objectName 对象名
   */
  deleteObject(objectName: string): Promise<any>;
  /**
   * 列出对象
   * @param prefix 前缀
   */
  listObjects(prefix: string, opts?: { recursive?: boolean }): Promise<any>;
  /**
   * 复制对象
   * @param sourceObject 源对象
   * @param targetObject 目标对象
   */
  copyObject: Client['copyObject'];
}
