import { Client, ItemBucketMetadata } from 'minio';
import { OssBaseOperation } from './core/type.ts';
type OssBaseOptions = {
  /**
   * 已经初始化好的minio client
   */
  client?: Client;
  /**
   * 桶名
   */
  bucketName: string;
};
export class OssBase implements OssBaseOperation {
  client?: Client;
  bucketName: string;
  constructor(opts: OssBaseOptions) {
    if (!opts.client) {
      throw new Error('client is required');
    }
    this.bucketName = opts.bucketName;
    this.client = opts.client;
  }
  async getObject(objectName: string) {
    const bucketName = this.bucketName;
    const obj = await this.client.getObject(bucketName, objectName);
    return obj;
  }
  async putObject(objectName: string, data: Buffer | string, metaData?: ItemBucketMetadata) {
    const size = data.length;
    const bucketName = this.bucketName;
    const obj = await this.client.putObject(bucketName, objectName, data, size, metaData);
    return obj as any;
  }
  async deleteObject(objectName: string) {
    const bucketName = this.bucketName;
    const obj = await this.client.removeObject(bucketName, objectName);
    return obj;
  }
  async listObjects(prefix: string) {
    const bucketName = this.bucketName;
    const obj = this.client.listObjects(bucketName, prefix);
    return obj;
  }
  async fPutObject(objectName: string, filePath: string, metaData?: ItemBucketMetadata) {
    const bucketName = this.bucketName;
    const obj = await this.client.fPutObject(bucketName, objectName, filePath, metaData);
    return obj as any;
  }
  async statObject(objectName: string) {
    const bucketName = this.bucketName;
    const obj = await this.client.statObject(bucketName, objectName);
    return obj;
  }
  async copyObject(sourceObject: any, targetObject: any) {
    const bucketName = this.bucketName;
    const obj = await this.client.copyObject(bucketName, sourceObject, targetObject);
    return obj;
  }
}
